@@ -15,9 +15,9 @@ test_that("myrpois works on linux", {
     expect_equal(x, ans)
   } else {
     ans <- c(-9, -2, -1, -2, -2, 0, 1, 2, 2, 3, 8)
-    if (filesstrings::all_equal(x, ans)) {  # r-hub fedora
-    expect_equal(x, ans)
-    } else {  # CRAN fedora
+    if (filesstrings::all_equal(x, ans)) { # r-hub fedora
+      expect_equal(x, ans)
+    } else { # CRAN fedora
       ans <- c(-4, -2, -3, -3, -2, 0, 0, 1, 5, 1, 6)
       expect_equal(x, ans)
     }
@@ -29,7 +29,7 @@ test_that("myrpois works on windows", {
   myrp <- myrpois(-5:5)
   if (filesstrings::all_equal(myrp, c(-2, -5, -6, -2, 0, 0, 1, 0, 4, 6, 5))) {
     expect_equal(myrp, c(-2, -5, -6, -2, 0, 0, 1, 0, 4, 6, 5))
-  } else {  # R 3.5.0 on win-builder
+  } else { # R 3.5.0 on win-builder
     expect_equal(myrp, c(-6, -4, -2, -1, -1, 0, 1, 6, 4, 6, 7))
   }
 })
@@ -37,8 +37,10 @@ test_that("myrpois works on windows", {
 test_that("myrbern works on mac", {
   skip_if_not(get_os() == "mac")
   set.seed(1)
-  expect_equal(myrbern(seq(0.1, 0.9, length.out = 7)),
-               c(0, 0, 1, 1, 0, 0, 1))
+  expect_equal(
+    myrbern(seq(0.1, 0.9, length.out = 7)),
+    c(0, 0, 1, 1, 0, 0, 1)
+  )
 })
 test_that("myrbern works on linux", {
   skip_if_not(get_os() == "linux")
@@ -46,7 +48,7 @@ test_that("myrbern works on linux", {
   x <- myrbern(seq(0.1, 0.9, length.out = 7))
   if (filesstrings::all_equal(x, c(0, 0, 1, 1, 0, 0, 1))) {
     expect_equal(x, c(0, 0, 1, 1, 0, 0, 1))
-  } else {  # fedora
+  } else { # fedora
     expect_equal(x, c(0, 1, 1, 0, 0, 1, 1))
   }
 })
@@ -56,10 +58,9 @@ test_that("myrbern works on windows", {
   myrb <- myrbern(seq(0.1, 0.9, length.out = 7))
   if (filesstrings::all_equal(myrb, c(0, 0, 1, 1, 0, 0, 1))) {
     expect_equal(myrb, c(0, 0, 1, 1, 0, 0, 1))
-  } else {  # R 3.5.0 on win-builder
+  } else { # R 3.5.0 on win-builder
     expect_equal(myrb, c(0, 0, 0, 0, 1, 1, 1))
   }
-
 })
 
 test_that("rfromboxes works on mac", {
@@ -73,7 +74,7 @@ test_that("rfromboxes works on linux", {
   x <- rfromboxes(10, 1:5)
   if (filesstrings::all_equal(x, c(0, 2, 2, 1, 5))) {
     expect_equal(x, c(0, 2, 2, 1, 5))
-  } else {  # fedora
+  } else { # fedora
     expect_equal(x, c(1, 2, 2, 3, 2))
   }
 })
@@ -83,21 +84,33 @@ test_that("rfromboxes works on windows", {
   rfb <- rfromboxes(10, 1:5)
   if (filesstrings::all_equal(rfb, c(0, 2, 2, 1, 5))) {
     expect_equal(rfb, c(0, 2, 2, 1, 5))
-  } else {  # R 3.5.0 on win-builder
+  } else { # R 3.5.0 on win-builder
     expect_equal(rfb, c(1, 2, 2, 3, 2))
   }
 })
 
 test_that("rfromboxes errors correctly", {
-  expect_error(rfromboxes(10, 1:3),
-               paste0("`n` must be less than or equal to the total ",
-                      "number of balls.*",
-                      "You have.*n = ", 10, ".*6 balls"))
-  expect_error(rfromboxes(10, 1:5, 1:11),
-               paste0("The length of `weights` must be equal to ",
-                      "the length of `balls`.", ".*",
-                      "You have 5 elements in `balls` and ",
-                      "11 elements in `weights`."))
+  expect_error(
+    rfromboxes(10, 1:3),
+    paste0(
+      "`n` must be less than or equal to the total ",
+      "number of balls.*",
+      "You have.*n = ", 10, ".*6 balls"
+    )
+  )
+  expect_error(
+    rfromboxes(10, 1:5, 1:11),
+    paste0(
+      "The length of `weights` must be equal to ",
+      "the length of `balls`.", ".*",
+      "You have 5 elements in `balls` and ",
+      "11 elements in `weights`."
+    )
+  )
+})
+
+test_that("`rfromboxes()` edge cases work correctly", {
+  expect_equal(rfromboxes(0, 1:3), rep(0, 3))
 })
 
 test_that("rtoboxes works on mac", {
@@ -111,7 +124,7 @@ test_that("rtoboxes works on linux", {
   x <- rtoboxes(10, 4)
   if (filesstrings::all_equal(x, c(0, 4, 1, 5))) {
     expect_equal(x, c(0, 4, 1, 5))
-  } else {  # fedora
+  } else { # fedora
     expect_equal(x, c(2, 6, 0, 2))
   }
 })
@@ -121,22 +134,34 @@ test_that("rtoboxes works on windows", {
   rtb <- rtoboxes(10, 4)
   if (filesstrings::all_equal(rtb, c(0, 4, 1, 5))) {
     expect_equal(rtb, c(0, 4, 1, 5))
-  } else {  # R 3.5.0 on win-builder
+  } else { # R 3.5.0 on win-builder
     expect_equal(rtb, c(2, 6, 0, 2))
   }
 })
 
 test_that("rtoboxes errors correctly", {
-  expect_error(rtoboxes(10, 4, capacities = 1:5),
-               paste0("The length of `capacities` must be equal to ",
-                      "the number of boxes.*",
-                      "You have 4 boxes and 5 .*capacities"))
-  expect_error(rtoboxes(10, 4, 1:11),
-               paste0("The length of `weights` must be equal to ",
-                      "the number of boxes.", ".*",
-                      "You have 4 boxes and ",
-                      "11 elements in `weights`."))
-  expect_error(rtoboxes(20, 5, capacities = 1:5),
-               paste("You have `n = 20` balls but your 5 boxes only have the",
-                     "capacity for a total of 15 balls"))
+  expect_error(
+    rtoboxes(10, 4, capacities = 1:5),
+    paste0(
+      "The length of `capacities` must be equal to ",
+      "the number of boxes.*",
+      "You have 4 boxes and 5 .*capacities"
+    )
+  )
+  expect_error(
+    rtoboxes(10, 4, 1:11),
+    paste0(
+      "The length of `weights` must be equal to ",
+      "the number of boxes.", ".*",
+      "You have 4 boxes and ",
+      "11 elements in `weights`."
+    )
+  )
+  expect_error(
+    rtoboxes(20, 5, capacities = 1:5),
+    paste(
+      "You have `n = 20` balls but your 5 boxes only have the",
+      "capacity for a total of 15 balls"
+    )
+  )
 })
