@@ -5,8 +5,18 @@ test_that("poly_fits work works", {
   m <- matrix(1:4, nrow = 2)
   expect_error(poly_fit_cols(m, 9), "too short")
   m <- matrix(runif(50), ncol = 5)
-  mNA <- m %T>% {.[, 1] <- NA}
+  mNA <- m %T>% {
+    .[, 1] <- NA
+  }
   expect_equal(poly_fit_cols(mNA, 2),
-               poly_fit_cols(m, 2) %T>% {.[, 1] <- NA},
-               check.attributes = FALSE)
+    poly_fit_cols(m, 2) %T>% {
+      .[, 1] <- NA
+    },
+    check.attributes = FALSE
+  )
+  x <- matrix(sample(1:100, 20), ncol = 2)
+  x[1, 1] <- NA
+  y <- x
+  y[3, 1] <- NA
+  expect_equal(poly_fit_cols(x, 3), poly_fit_cols(y, 3))
 })
